@@ -1,5 +1,5 @@
 /**
- * $Id: editor_template_src.js 852 2008-05-27 05:52:09Z spocke $
+ * $Id: editor_template_src.js 901 2008-08-18 11:44:21Z spocke $
  *
  * @author Moxiecode
  * @copyright Copyright  2004-2008, Moxiecode Systems AB, All rights reserved.
@@ -75,7 +75,8 @@
 				theme_advanced_more_colors : 1,
 				theme_advanced_row_height : 23,
 				theme_advanced_resize_horizontal : 1,
-				theme_advanced_resizing_use_cookie : 1
+				theme_advanced_resizing_use_cookie : 1,
+				readonly : ed.settings.readonly
 			}, ed.settings);
 
 			if ((v = s.theme_advanced_path_location) && v != 'none')
@@ -92,6 +93,13 @@
 					ed.dom.loadCSS(ed.baseURI.toAbsolute("themes/advanced/skins/" + ed.settings.skin + "/content.css"));
 			});
 
+			ed.onActivate.add(function(ed) {
+				DOM.addClass(DOM.get(ed.id + '_tbl'), 'mceEditorFocus');
+			});
+			ed.onDeactivate.add(function(ed) {
+				DOM.removeClass(DOM.get(ed.id + '_tbl'), 'mceEditorFocus');
+			});
+
 			ed.onSetProgressState.add(function(ed, b, ti) {
 				var co, id = ed.id, tb;
 
@@ -431,7 +439,9 @@
 
 			// Resize iframe and container
 			DOM.setStyle(ifr, 'height', h - dh);
-			DOM.setStyles(e, {width : w, height : h});
+			
+			if (s.theme_advanced_toolbar_location != 'external')
+				DOM.setStyles(e, {width : w, height : h});
 		},
 
 		destroy : function() {
@@ -447,13 +457,19 @@
 		_simpleLayout : function(s, tb, o, p) {
 			var t = this, ed = t.editor, lo = s.theme_advanced_toolbar_location, sl = s.theme_advanced_statusbar_location, n, ic, etb, c;
 
+			if (s.readonly) {
+				n = DOM.add(tb, 'tr');
+				n = ic = DOM.add(n, 'td', {'class' : 'mceIframeContainer'});
+				return ic;
+			}
+
 			// Create toolbar container at top
 			if (lo == 'top')
 				t._addToolbars(tb, o);
 
 			// Create external toolbar
 			if (lo == 'external') {
-				n = c = DOM.create('div', {style : 'position:relative'});
+				n = c = DOM.create('div');
 				n = DOM.add(n, 'div', {id : ed.id + '_external', 'class' : 'mceExternalToolbar'});
 				DOM.add(n, 'a', {id : ed.id + '_external_close', href : 'javascript:;', 'class' : 'mceExternalClose'});
 				n = DOM.add(n, 'table', {id : ed.id + '_tblext', cellSpacing : 0, cellPadding : 0});
@@ -469,7 +485,6 @@
 				ed.onMouseUp.add(function() {
 					var e = DOM.get(ed.id + '_external');
 					DOM.show(e);
-
 					DOM.hide(lastExtID);
 
 					var f = Event.add(ed.id + '_external_close', 'click', function() {
@@ -477,9 +492,6 @@
 						Event.remove(ed.id + '_external_close', 'click', f);
 					});
 
-					DOM.show(e);
-					DOM.setStyle(e, 'top', 0 - DOM.getRect(ed.id + '_tblext').h - 1);
-
 					// Fixes IE rendering bug
 					DOM.hide(e);
 					DOM.show(e);
@@ -540,7 +552,8 @@
 						to = cf.createToolbar("toolbar" + i);
 						t._addControls(v, to);
 						DOM.setHTML(n, to.renderHTML());
-						o.deltaHeight -= s.theme_advanced_row_height;
+						if (s.theme_advanced_toolbar_location != 'external')
+							o.deltaHeight -= s.theme_advanced_row_height;
 				}
 			});
 
@@ -642,7 +655,8 @@
 						if (s.theme_advanced_resize_horizontal)
 							c.style.width = Math.max(10, o.cw) + 'px';
 
-						c.style.height = Math.max(10, o.ch) + 'px';
+						if (s.theme_advanced_toolbar_location != 'external')
+							c.style.height = Math.max(10, o.ch) + 'px';
 						DOM.get(ed.id + '_ifr').style.height = Math.max(10, parseInt(o.ch) + t.deltaHeight) + 'px';
 					});
 				}
@@ -720,7 +734,9 @@
 							if (s.theme_advanced_resize_horizontal)
 								c.style.width = Math.max(10, r.w + r.dx) + 'px';
 
-							c.style.height = Math.max(10, r.h + r.dy) + 'px';
+							if (s.theme_advanced_toolbar_location != 'external')
+								c.style.height = Math.max(10, r.h + r.dy) + 'px';
+
 							ifr.style.height = Math.max(10, ifr.clientHeight + r.dy) + 'px';
 
 							if (s.theme_advanced_resizing_use_cookie) {
@@ -743,6 +759,9 @@
 		_nodeChanged : function(ed, cm, n, co) {
 			var t = this, p, de = 0, v, c, s = t.settings;
 
+			if (s.readonly)
+				return;
+
 			tinymce.each(t.stateControls, function(c) {
 				cm.setActive(c, ed.queryCommandState(t.controls[c][1]));
 			});
